darkhistory.physics.hbar — DarkHistory documentation

- Repository
- DarkHistory documentation
- DarkHistory
- darkhistory
- darkhistory.physics

- index
- modules
- next
- previous

# darkhistory.physics.hbar

`darkhistory.physics.` `hbar` = 6.58211951e-16

  hbar in eV s.

#### Previous topic

darkhistory.physics.mHe

#### Next topic

darkhistory.physics.c

### This Page

Show Source

- © Copyright 2019, Hongwan Liu, Gregory Ridgway and Tracy Slatyer.
- Created using Sphinx 1.8.5.